{% load i18n staticfiles enterprise %}

<div class="consent-input-container login-register">
  <form name="data-sharing-consent" method="POST" id="data-sharing">
    {% csrf_token %}
    <input class="background-input data-consent-checkbox" type="checkbox" name="data_sharing_consent" id="data-consent-checkbox" value="True"/>
    <p class="agreement-text">
      <label for="data-consent-checkbox">{{ agreement_text }}</label>
    </p>
    <button type="submit" class="background-input consent-agreement-button" id="consent-button" disabled>{{ continue_text }}</button>
    <button type="button" class="failure-link background-input" id="failure-link" data-toggle="modal" data-target="#consent-confirmation-modal">
      {{ abort_text }}
    </button>
    <input type="hidden" name="enterprise_customer_uuid" value="{{ enterprise_customer.uuid }}" />
    {% if course_specific and course_id %}
      <input type="hidden" name="course_id" value="{{ course_id }}" />
    {% endif %}
    {% if program_specific and program_uuid %}
      <input type="hidden" name="program_uuid" value="{{ program_uuid }}" />
    {% endif %}
    {% if redirect_url %}
      <input type="hidden" name="redirect_url" value="{{ redirect_url }}" />
    {% endif %}
    {% if failure_url %}
      <input type="hidden" name="failure_url" value="{{ failure_url }}" />
    {% endif %}
    {% if license_uuid %}
      <input type="hidden" name="license_uuid" value="{{ license_uuid }}" />
    {% endif %}
    {% if defer_creation %}
      <input type="hidden" name="defer_creation" value="true" />
    {% endif %}
  </form>
</div>
<br/>
