# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-01-29 16:34


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0038_auto_20180122_1427'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomerreportingconfiguration',
            name='initialization_vector',
            field=models.BinaryField(blank=True, help_text='This is the initialization vector used to encrypt the password using AESencr', max_length=32, null=True, verbose_name='Password Encryption Initialization Vector'),
        ),
        migrations.AlterField(
            model_name='enterprisecustomerreportingconfiguration',
            name='password',
            field=models.BinaryField(blank=True, max_length=256, null=True, verbose_name='Password for the protected zip file.'),
        ),
    ]
